@@ -20,7 +20,7 @@ import dnslib
 # bin/protoc --python_out=. dnstap.proto
 
 # more informations on dnstap http://dnstap.info/
-from dnstap_receiver import dnstap as dnstap_pb2
+from dnstap_receiver import dnstap_pb2
 
 # framestreams decoder
 from dnstap_receiver import fstrm
@@ -49,7 +49,7 @@ parser.add_argument("-c", help="external config file")
 async def cb_ondnstap(dnstap_decoder, payload, cfg, queue):
     """on dnstap"""
     # decode binary payload
-    dnstap_decoder.parse_from_bytes(payload)
+    dnstap_decoder.ParseFromString(payload)
     dm = dnstap_decoder.message
     
     # filtering by dnstap identity ?
@@ -64,28 +64,28 @@ async def cb_ondnstap(dnstap_decoder, payload, cfg, queue):
             "source-ip": "-"}
     
     # decode type message
-    tap["message"] = DNSTAP_TYPE.get(dm.type.value, "-")
-    tap["protocol"] = DNSTAP_FAMILY.get(dm.socket_family.value, "-")
-    tap["transport"] = DNSTAP_PROTO.get(dm.socket_protocol.value, "-")
+    tap["message"] = DNSTAP_TYPE.get(dm.type, "-")
+    tap["protocol"] = DNSTAP_FAMILY.get(dm.socket_family, "-")
+    tap["transport"] = DNSTAP_PROTO.get(dm.socket_protocol, "-")
 
     # decode query address
-    if len(dm.query_address) and dm.socket_family.value == 1:
+    if len(dm.query_address) and dm.socket_family == 1:
         tap["source-ip"] = socket.inet_ntoa(dm.query_address)
-    if len(dm.query_address) and dm.socket_family.value == 2:
+    if len(dm.query_address) and dm.socket_family == 2:
         tap["source-ip"] = socket.inet_ntop(socket.AF_INET6, dm.query_address)
     tap["source-port"] = dm.query_port
     if tap["source-port"] == 0:
         tap["source-port"] = "-"
         
     # handle query message
-    if (dm.type.value % 2 ) == 1 :
+    if (dm.type % 2 ) == 1 :
         dnstap_parsed = dnslib.DNSRecord.parse(dm.query_message)
         tap["length"] = len(dm.query_message)
         d1 = dm.query_time_sec +  (round(dm.query_time_nsec ) / 1000000000)
         tap["timestamp"] = datetime.fromtimestamp(d1, tz=timezone.utc).isoformat()
         
     # handle response message
-    if (dm.type.value % 2 ) == 0 :
+    if (dm.type % 2 ) == 0 :
         dnstap_parsed = dnslib.DNSRecord.parse(dm.response_message)
         tap["length"] = len(dm.response_message)
         d2 = dm.response_time_sec + (round(dm.response_time_nsec ) / 1000000000) 
@@ -293,7 +293,7 @@ async def handle_output_stdout(output_cfg, queue):
         msg = convert_dnstap(fmt=output_cfg["format"], tapmsg=tapmsg)
         
         # print to stdout
-        print(msg.decode())
+        logging.info(msg.decode())
         
         # all done
         queue.task_done()
@@ -325,10 +325,10 @@ def start_receiver():
     try:
         cfg =  yaml.safe_load(pkgutil.get_data(__package__, 'dnstap.conf')) 
     except FileNotFoundError:
-        print("error: default config file not found")
+        logging.error("default config file not found")
         sys.exit(1)
     except yaml.parser.ParserError:
-        print("error: invalid default yaml config file")
+        logging.error("invalid default yaml config file")
         sys.exit(1)
     
     # update default config with command line arguments
@@ -343,17 +343,17 @@ def start_receiver():
             with open(args.c) as file:
                 cfg.update( yaml.safe_load(file) )
         except FileNotFoundError:
-            print("error: config file not found")
+            logging.error("external config file not found")
             sys.exit(1)
         except yaml.parser.ParserError:
-            print("error: invalid yaml config file")
+            logging.error("external invalid yaml config file")
             sys.exit(1)
             
     # init logging
     level = logging.INFO
     if cfg["verbose"]:
         level = logging.DEBUG
-    logging.basicConfig(format='%(asctime)s %(message)s', level=level)
+    logging.basicConfig(format='%(asctime)s %(message)s', stream=sys.stdout, level=level)
 
     # start receiver and get event loop
     logging.debug("Start receiver...")
